@@ -52,7 +52,7 @@ def append_archive(in_path, out_path, no_write=False, obj=False):
             cin = setinputs(input_archive)
             cout = setoutputs(out_path)
             conf = set(cin, cout)
-            alac.write(conf, new_archive)
+            write(conf, new_archive)
          return new_archive
    else: # object in_path
       output_archive = read(out_path)
